# FTL-Extract

## Description

FTL-Extract is a Python package that extracts Fluent keys from .py files
and generates a .ftl file with extracted keys.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable) to install
FTL-Extract.

``` bash
pip install FTL-Extract
```

## Usage

``` bash
ftl_extract code_path output_path
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.
